#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-3oIIRfVoOS4gLHGUVLzKl
key:                  pantry-0.8.3-3oIIRfVoOS4gLHGUVLzKl
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  5948746ef29e078c51e8c32d7d38729a
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-3oIIRfVoOS4gLHGUVLzKl
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-DAWEUfqGTZl4JS91alOoes
    ansi-terminal-1.1-D07LgEFqBSsB16qPkFlGoJ base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.3-JQYPmqUS1G44oaJXyg9Mm8
    casa-types-0.0.3-FXqliBnwmlfCJmPCy8lwZ2
    conduit-1.3.6.1-5Wps0pi1oaaLry3JJy7JDj
    conduit-extra-1.3.8-D1cAoE4PeUO1ETPOuTmgDF containers-0.6.7
    crypton-1.0.4-6IRicRqjyNE7xoN5ueDJgh
    crypton-conduit-0.2.3-nAfsL2xVYt9vqbaz0Ghsh
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.8-IjkptsKb97aGsbmkMN7av5
    generic-deriving-1.14.7-8JzkCcH4LI77b4NgLrMQa9
    hackage-security-0.6.3.2-1ihvx1nerhwGYVa0vTDlDq
    hpack-0.38.0-HneAeMUZt3pJpCL0L6J77t
    http-client-0.7.19-AyWBIywgc0PBRr7iUqe6iS
    http-client-tls-0.3.6.4-4YgfhhNbPqLLMZA7kcE7F0
    http-conduit-2.3.9.1-3DdpWeTlHdYL9J9Hv1hkGx
    http-download-0.2.1.0-4OU1bLVOZRB2xWPJQ3GKsP
    http-types-0.12.4-DIRo50xDRxbE4a3m2IKFXS
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-5H6FsM3EemmJOLKW8jzcT0
    path-0.9.6-5qrScexrF1579tuGcWHaqZ
    path-io-1.8.2-1IQK1jX11n31jfr1hOjzgT
    persistent-2.14.5.2-FDFSQJTxvpv4st0dNLm6e6
    persistent-sqlite-2.13.2.0-ArkGsdm4B1N886nk3NZq8L
    primitive-0.9.1.0-lW2EkZ3nJuWUNs0VgOCK
    resourcet-1.2.6-6VmvylmAyS7HrfWxVbJ0NO
    rio-0.1.24.0-4GonoOxSHhT8kMiAiSE4xj
    rio-orphans-0.1.2.0-KWJ9egioMyDIuPKso0tDX4
    rio-prettyprint-0.1.8.0-CnZ4CQbnyb06xg0MErAy6k
    tar-conduit-0.4.1-A9VmFMId7LiCAaFEv2rRNy text-2.0.2
    text-metrics-0.3.3-C5T4moDy4P4J1ASJ9lmvtr time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-ASe7aNqaNhI5dOeaFzNzBW
    unliftio-0.2.25.1-4sSt3OjSW4r1pFFb98bYkM
    unordered-containers-0.2.20.1-BaP0PevI27VLqsaWB0hjeu
    vector-0.13.2.0-CDuZD6JA02PF3ZzyJqHF4G
    yaml-0.11.11.2-8eLFXIdsE0bB7sOWbJDpuK
    zip-archive-0.4.3.2-4ySSWgUC9ae4GPGjv5cnQn

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

